## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, eval=FALSE)

## ----Figure1, eval=TRUE, echo=FALSE, out.width = '100%', fig.align = "center"----
knitr::include_graphics("priorCON_flowchart.png")

## ----Figure2, eval=TRUE, echo=FALSE, out.width = '100%', fig.align = "center"----
knitr::include_graphics("priorCON_fig2.png")

## ----Figure3, eval=TRUE, echo=FALSE, out.width = '100%', fig.align = "center"----
knitr::include_graphics("priorCON_fig3.png")

## ----Figure4, eval=TRUE, echo=FALSE, out.width = '100%', fig.align = "center"----
knitr::include_graphics("priorCON_fig4.png")

## ----Costraster, eval=TRUE, echo=FALSE, out.width = '70%', fig.align = "center"----
knitr::include_graphics("cost_raster.png")

## ----Features, eval=TRUE, echo=FALSE, out.width = '70%', fig.align = "center"----
knitr::include_graphics("features.png")

## ----Basic, eval=TRUE, echo=FALSE, out.width = '70%', fig.align = "center"----
knitr::include_graphics("basic_output.png")

## ----Connectivity, eval=TRUE, echo=FALSE, out.width = '70%', fig.align = "center"----
knitr::include_graphics("connectivity_output.png")

